@@ -56,7 +56,7 @@ class ClusterAccessUnsupported(Exception):
 
 def global_options(fn):
     """Attaches hidden '-n/--namespace' and '--context' options to the command that updates the namespace on the
-       Environment object in the context."""
+    Environment object in the context."""
 
     def callback(ctx, param, value):
         if not ctx.obj:
@@ -253,7 +253,7 @@ def opsview(env: Environment):
     env.kubectl.exec("proxy", "--accept-hosts=.*")
 
 
-@click_cli.command("logtail", context_settings=dict(ignore_unknown_options=True, help_option_names=[],))
+@click_cli.command("logtail", context_settings=dict(ignore_unknown_options=True, help_option_names=[]))
 @click.argument("args", nargs=-1, type=click.UNPROCESSED)
 @click.pass_obj
 def logtail(env: Environment, args):
@@ -315,7 +315,7 @@ def do_login(env: Environment, cluster):
 
     zalando_kubectl.kube_permissions.check_cluster_permissions(url, alias, token)
 
-    with Action("Writing kubeconfig for {}..".format(url,)):
+    with Action("Writing kubeconfig for {}..".format(url)):
         kube_config.update(url, alias, token)
 
 
@@ -513,10 +513,11 @@ def unblock_cluster_update(env: Environment):
 
 
 @click_cli.command("tunnel")
+@click.option("--address", help="Addresses to listen on (comma separated), similar to kubectl port-forward")
 @click.argument("target", required=True)
 @click.argument("ports", required=True, nargs=-1, type=PortMappingParamType())
 @click.pass_obj
-def tunnel(env: Environment, target, ports):
+def tunnel(env: Environment, address, target, ports):
     """Forward a local port to a remote endpoint through the cluster.
 
     The command starts a socat pod in your cluster that forwards a port to
@@ -611,10 +612,12 @@ def tunnel(env: Environment, target, ports):
         .strip()
     )
 
-    info("You can now connect to {} via 127.0.0.1 ..".format(target))
+    info("You can now connect to {} via {} ..".format(target, address if address else "127.0.0.1"))
 
     # port-forward to the pod
     cmdline = ["port-forward", pod_name]
+    if address:
+        cmdline.append("--address={}".format(address))
     for i, port in enumerate(ports):
         local_port = port[0]
         cmdline += ["{}:{}".format(local_port, base_port + i)]
